import json
import sysconfig
import yaml
import os
import pika



class RabbitmqUtil:
    """Rabbitmq工具类"""
    connection = None
    channel = None

    def __init__(self, host, vhost, username, password, port=5672):
        try:
            credential = pika.PlainCredentials(username, password)
            self.connection = pika.BlockingConnection(
                pika.ConnectionParameters(host, port, vhost, credential, heartbeat=0))
            self.channel = self.connection.channel()
        except():
            print("rabbitmq init error, please check the config")

    def close(self):
        """关闭连接"""
        if self.connection:
            self.connection.close()
        else:
            print("connection already disconnected")

    def bind_queue_exchange(self, queue, exchange, routing_key):
        """绑定queue和exchange"""
        self.channel.queue_bind(exchange=exchange, queue=queue, routing_key=routing_key)

    def new_queue(self, queue):
        """声明queue，如不存在，则创建"""
        self.channel.queue_declare(queue=queue, durable=True, arguments={'x-message-ttl': 259200000})

    def del_queue(self, queue):
        """Delete the queue"""
        self.channel.queue_delete(queue)

    def new_exchange(self, exchange):
        """声明exchange，如不存在，则创建"""
        self.channel.exchange_declare(exchange=exchange, durable=True, exchange_type='topic')

    def del_exchange(self, exchange):
        """Delete the exchange"""
        self.channel.exchange_delete(exchange=exchange)

    def callback(self, body):
        """接收处理消息的回调函数"""
        super()
        print(str(body).replace('b', '').replace('\'', ''))

    def public_msg(self, exchange, routing_key, json):
        """发布消息"""
        self.channel.basic_publish(exchange=exchange, routing_key=routing_key, body=json)

    def consume_msg(self, queue):
        """订阅消息"""
        self.channel.basic_consume(queue, self.callback, True)
        self.channel.start_consuming()




import setuptools

setuptools.setup(
    include_package_data=True,
    install_requires=[
        "pytest==8.2.2",
        "pytest-base-url==2.1.0",
        "python-slugify==8.0.4",
        "openpyxl>=3.0.9",
        "jsonpath==0.82",
        "loguru==0.7.2",
        "PyYAML==5.3.1",
        "playwright==1.44.0",
        "requests==2.24.0",
        "requests-toolbelt==1.0.0",
        "xlrd==2.0.1",
        "PyMySQL==0.10.1",
        "ruamel.yaml==0.18.5",
        "pytest-rerunfailures==14.0",
        "allure-pytest==2.13.5",
        #"pytest-asyncio==0.23.6",
        "pytest-mimesis==1.1.0",
        "pytest-bdd==7.1.2",
        "faker==21.0.0",
        "pytest-xdist==2.5.0",
        "allure-python-commons==2.13.5",
        "xlrd==2.0.1",
        "xlutils==2.0.0",
        "xlwt==1.3.0",
        "zipp==3.7.0",
        "xmltodict==0.13.0",
        "python-dateutil==2.8.2",
        #"lxml==4.4.0",
        #"lxml==4.8.0",
        "lxml==4.9.3",
        "assertpy==1.1",
        "deepdiff==5.8.1",
        "dnspython==2.2.1",
        "jsonschema==4.17.0",
        "xmlschema==1.0.14",
        "pymongo==3.5.1",
        "redis-py-cluster==2.1.3",
        "redis==3.5.3",
        "bs4==0.0.1",
        "Jinja2==3.1.2",
        "jmespath==1.0.1",
        "paramiko==3.3.0",
        "crypto == 1.4.1",
        "pandas ==2.0.3",
        "pyexcel==0.7.0",
        "pyexcel-xls==0.7.0",
        "ext-list==1.1.1",
        "jsonpath-ng==1.6.1",
        "jmespath==1.0.1"
    ],
    entry_points={"pytest11": ["playwright = test.plugin.pytest_playwright"]},
    classifiers=[
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
        "Framework :: Pytest",
    ],
    python_requires=">=3.6"
)
